# Epydoc Log

Epydoc started at Sat Aug 23 21:57:02 2014

## In /home/lee/untdl/untdl/__init__.py: Source code parsing failed (but introspection was successful).

Error: Error during parsing: invalid syntax (/home/lee/untdl/untdl/__init__.py, line 58) -- Attempted relative import in non-package, or beyond toplevel package

## In /home/lee/untdl/untdl/__tcod.py: No documentation available!

Docstring Warning:

    Failed identifier crossreference targets:
    - Console.drawChar
          (from untdl)
    - Typewriter
          (from untdl._MetaConsole.draw_str)
          (from untdl._MetaConsole.write)
    - addChar
          (from untdl._MetaConsole.get_cursor)
    - addStr
          (from untdl._MetaConsole.get_cursor)
    - event.isWindowClosed
          (from untdl.event)
    - event.keyWait
          (from untdl.event)
    - untdl.setFont
          (from untdl)

## Epydoc Options

configfiles | `=` | `['epydoc.config']`
include_log | `=` | `True`
inheritance | `=` | `'included'`
names | `=` | `['../untdl']`
prj_name | `=` | `'python-untdl'`
prj_url | `=` | `'https://github.com/leecannon/untdl'`
show_private | `=` | `False`
simple_term | `=` | `True`
target | `=` | `'./'`
verbosity | `=` | `5`
action | `=` | `'html'`
css | `=` | `None`
debug | `=` | `False`
docformat | `=` | `'epytext'`
dotpath | `=` | `None`
exclude | `=` | `['__tcod']`
exclude_introspect | `=` | `[]`
exclude_parse | `=` | `[]`
external_api | `=` | `[]`
external_api_file | `=` | `[]`
external_api_root | `=` | `[]`
fail_on | `=` | `None`
graph_font | `=` | `None`
graph_font_size | `=` | `None`
graphs | `=` | `[]`
help_file | `=` | `None`
include_source_code | `=` | `True`
introspect | `=` | `True`
list_classes_separately | `=` | `False`
load_pickle | `=` | `False`
parse | `=` | `True`
prj_link | `=` | `None`
profile | `=` | `False`
pstat_files | `=` | `[]`
quiet | `=` | `0`
redundant_details | `=` | `False`
show_frames | `=` | `True`
show_imports | `=` | `False`
src_code_tab_width | `=` | `8`
top_page | `=` | `None`
verbose | `=` | `0`

Epydoc finished at Sat Aug 23 21:57:03 2014

(Elapsed time: 0 seconds)